@@ -8,10 +8,9 @@
 
 from dataclasses import dataclass
 
+from detector_connector import DetectorSettings
 
-@dataclass
-class DefocusSettings:
-    stream_url: str
+
+@dataclass(kw_only=True, frozen=True)
+class DefocusSettings(DetectorSettings):
     freq_diff_threshold: float
-    created_at: float | None = None
-    updated_at: float | None = None
